import { AxiosRequestConfig } from 'axios';
import { Product } from './product/product';
import { Store } from './store/store';
import { TokenHandler } from './auth/tokenHandler';
import { Order } from './order/order';
import { Promotion } from './promotion/promotion';
import { Recipe } from './recipe/recipe';
import { User } from './user/user';
import { Category } from './category/category';
import { List } from './list/list';
export interface JumboClientOptions {
    username?: string;
    password?: string;
    token?: string;
    verbose?: boolean;
    axiosConfig?: AxiosRequestConfig;
    apiVersion?: number;
}
export declare class Jumbo {
    private endpoint;
    private readonly client;
    private verbose;
    jumboCategory: Category;
    jumboList: List;
    jumboOrder: Order;
    jumboProduct: Product;
    jumboPromotion: Promotion;
    jumboRecipe: Recipe;
    jumboStore: Store;
    jumboUser: User;
    tokenHandler?: TokenHandler;
    /**
     * @param options Options for the client
     * @param options.username Jumbo account username (e-mail)
     * @param options.password Jumbo account password
     * @param options.token Jumbo access token
     * @param options.verbose Whether to log requests (default false)
     * @param options.axiosConfig Axios configuration (defaults to TLSv1.2)
     * @param options.apiVersion Jumbo API version (defaults to 17)
     */
    constructor(options?: JumboClientOptions);
    category(): Category;
    list(): List;
    order(): Order;
    product(): Product;
    promotion(): Promotion;
    recipe(): Recipe;
    store(): Store;
    user(): User;
    /**
     * Function that creates a new TokenHandler for given username and password
     * @param username Jumbo account username (e-mail)
     * @param password Jumbo account password
     */
    login(username: string, password: string): void;
    /**
     * Function that creates a new TokenHandler for given access token
     * @param token Jumbo access token
     */
    loginWithToken(token: string): void;
    /**
     * PUT request
     * @param path Endpoint URL (without start)
     * @param body Body of PUT (if any)
     * @param additionalRequestOptions Any additional headers or queries
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    put(path: string, body?: any, additionalRequestOptions?: AdditionalRequestOptions, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * POST request
     * @param path Endpoint URL (without start)
     * @param body Body of POST
     * @param additionalRequestOptions Any additional headers or queries
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    post(path: string, body: any, additionalRequestOptions?: AdditionalRequestOptions, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * GET request
     * @param path Endpoint URL (without start)
     * @param additionalRequestOptions Any additional headers or queries
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    get(path: string, additionalRequestOptions?: AdditionalRequestOptions, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * Generic request method
     * @param path Endpoint URL (without start)
     * @param method Request method (GET, POST, PUT, DELETE)
     * @param body Body in case of POST and PUT
     * @param additionalRequestOptions Any additional headers or queries
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    request(path: string, method: requestMethod, body?: any, additionalRequestOptions?: AdditionalRequestOptions, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * Helper function to create headers for request
     * @param extraHeaders Any extra header options
     */
    createHeader(authRequired?: boolean, extraHeaders?: Headers): Headers;
    /**
     * Helper function to create request URL
     * @param path Path to endpoint (without ENDPOINT in .env)
     * @param query Any query options
     */
    createURL(path: string, query?: Query): string;
}
/**
 * Simple enum for different request methods
 */
export declare enum requestMethod {
    GET = "GET",
    POST = "POST",
    PUT = "PUT"
}
/**
 * Query interface that is converted to {@URLSearchParams}
 */
export interface Query {
    [key: string]: string;
}
export interface Headers {
    [key: string]: string;
}
/**
 * Interface that combines additional headers and query options
 */
export interface AdditionalRequestOptions {
    headers?: Headers;
    query?: Query;
}
